-- "Master Client" example LUA plug-in, by Pete Dowson, October 2009
-- To make the Server FS act as a slave, following the Client FS acting as Master

-- The SOCKET module is built into FSUIPC, but is not active until "required"
local socket = require"socket"

-- Set the host name to the name of the PC running the Server
host = "<put the name of your slave PC here>";

-- The port must match the port selected in the client and not clash with others.
port = "8384"

function pass(...)
    local s = string.format(unpack(arg))
    io.stderr:write(s .. "\n")
end

local function fail(...)
    local s = string.format(unpack(arg))
    io.stderr:write("ERROR: " .. s .. "!\n")
		socket.sleep(3)
    os.exit()
end

local function processdata()
	lat, lon, alt, pitch, bank, hdgT =
		ipc.readStruct(0x0560,"3DD", "2SD", "1UD")

	-- This simply sets the aircraft position and attitude
	-- according to the parameters received

	-- we need to convert from FS units
	hdgT = (((hdgT * 360) / 65536)) / 65536
	lat = (lat * 90) / (10001750 * 65536 * 65536)
	lon = (lon * 360) /  (65536 * 65536 * 65536 * 65536)
	alt = (alt * 3.28084) / (65536 * 65536)
	pitch = (pitch * 360) / (65536 * 65536)
	bank = (bank * 360) / (65536 * 65536)

	s = "lat=" .. lat .. ",lon=" .. lon .. ",alt=" .. alt .. ",pch=" .. pitch .. ",bnk=" .. bank .. ",hdg=" .. hdgT
	
	-- now send it all in one string
  control:send(s .. "\n")
end

pass("attempting control connection...")
control, err = socket.connect(host, port)
if err then
	fail(err)
else
	pass("connected!")
end
control:setoption("tcp-nodelay", true)

while 1 do
  -- You may need to adjust the sleep time for smoothest results
	ipc.sleep(5)
	processdata()
  if control:receive() == nil then
  	pass("disconnected")
  	break
  end
end




