Vendor = "GoFlight"
Product = "RP48"
Device = 0  -- Multiple devices of the same name need increasing Device numbers

-- Use separate Lua plug-ins for separate cards!

-- NOTE: this can handle up to 16 rotaries only, using the first 64 "virtual buttons"
-- List the pairs here:

Rotaries = { 1,2,3,4,5,6,7,8} 

-- Example { 31, 30, 25, 22 } would be 31+30 for one, 25+22 for the next, and so on
-- Which is clockwise and which counterclockwise doesn't matter -- you'll get
-- fast and slow of each in any case

dev, rd, wrf, wr, init = com.openhid(Vendor, Product, Device, Report)

if dev == 0 then
   ipc.log("Could not open HID")
   ipc.exit()
end

-- Set the boundary time in milliseconds between
-- "fast" (shorter) and "slow" (longer) signalling

FastTimeLimit = 60 -- Adjust to taste

-- Polling time in milliseconds: should be much shorter than 
-- the boundary time

Pollrate = 20  -- same as 50 times per second

-- Initialise variables used to keep track of things
LastTimes = {}
Buttons = 0
PrevButtons = 0
Diff = 0

-- This function will be called by a time event, set at the end of the program before exit.
function poll(Time)
	-- read any data available from the device (only need most recent report)
  data, n = com.readlast(dev, rd)

	if n ~= 0 then
 		-- Data was returned, so get the status of all the possible "buttons" we are using
  	-- one value of 32 bits
		Buttons = com.gethidbuttons(dev, data)            

  	-- See if any changes occurred:
  	Diff = logic.Xor(Buttons, PrevButtons)
  	PrevButtons = Buttons
  	       
    if Diff ~= 0 then 
    	offset = 0x3340
    	buttonbit = 1
  		j = 1
   		while Rotaries[j] ~= nil do
				mask = logic.Shl(1, Rotaries[j]-1)   			
				if logic.And(Diff,mask) ~= 0 then
					-- This one changed
		   		-- See if changed in less than the "boundary" time
		   		thisbutton = buttonbit
    			if (LastTimes[j] ~= nil) and ((Time - LastTimes[j]) < FastTimeLimit) then
          	thisbutton = buttonbit + buttonbit  -- Use next higher button for fast
        	end
       		LastTimes[j] = Time
                        
      		-- Toggle a virtual button accordingly
       		ipc.togglebitsUD(offset, thisbutton)
				end
				
				j = j + 1
				buttonbit = 4 * buttonbit
				if logic.And(j,15) == 0 then
				   buttonbit = 1
				   offset = offset + 4
				end
  		end
		end
	end
end

event.timer(Pollrate, "poll")
