--------------------------------------------------------------------------
-- FSX Lua plug-in for thrust, pitch and mixture assimetry compensation --
--------------------------------------------------------------------------

-- [[Thrust, prop pitch and mixture assimetry compensation for twin engine aircraft. In this method, compensation is achieved by adding half of the detected assimetry to each engine throttle, pitch or mixture values.]] --


MaxThrottleAssimetry = 1000  -- maximum thrust assimetry allowed
MaxPitchAssimetry = 1500     -- maximum prop pitch assimetry allowed
MaxMixtureAssimetry = 1000   -- maximum mixture assimetry allowed


while 1 do

    ipc.sleep(500) -- do nothing for half a second

    -- Throttle compensation
    Throttle1Now = ipc.readSW(0x088C)
    Throttle2Now = ipc.readSW(0x0924)
    if (Throttle1Now > 0) and (Throttle2Now > 0) then -- delete this line if reverse throttle compensation is required
        if math.abs(Throttle1Now - Throttle2Now) < MaxThrottleAssimetry then
            -- there's an assimetric thrust, let's compensate
            MidThrottleValue = (Throttle1Now + Throttle2Now)/2
            ipc.writeSW(0x088C, MidThrottleValue)
            ipc.writeSW(0x0924, MidThrottleValue)
            -- done!
        end
    end -- delete this line if reverse throttle compensation is required

    -- Prop pitch compensation   
    Pitch1Now = ipc.readSW(0x088E)
    Pitch2Now = ipc.readSW(0x0926)
    if (Pitch1Now > 0) and (Pitch2Now > 0) then -- delete this line if reverse pitch compensation is required
        if math.abs(Pitch1Now - Pitch2Now) < MaxPitchAssimetry then
            -- there's an assimetric pitch, let's compensate
            MidPitchValue = (Pitch1Now + Pitch2Now)/2
            ipc.writeSW(0x088E, MidPitchValue)
            ipc.writeSW(0x0926, MidPitchValue)
            -- done!
        end
    end -- delete this line if reverse pitch compensation is required

    -- Mixture compensation   
    Mixture1Now = ipc.readSW(0x0890)
    Mixture2Now = ipc.readSW(0x0928)
    if math.abs(Mixture1Now - Mixture2Now) < MaxMixtureAssimetry then
        -- there's an assimetric mixture, let's compensate
        MidMixtureValue = (Mixture1Now + Mixture2Now)/2
        ipc.writeSW(0x0890, MidMixtureValue)
        ipc.writeSW(0x0928, MidMixtureValue)
        -- done!
    end

end

-- by Muas, November 2009