-- "Liar" example LUA plug-in for FSUIPC4/ESPIPC only, by Pete Dowson, January 2009

-- Loop till flag 0 is set
while ipc.testflag(0) == false do

-- Get all of the data we want to distort
-- (Note that it is all read in one instruction, so that all values
-- apply to the same FS frame, and we read the ORIGINALS not the ones
-- we ask FSUIPC to supply others). 

gs, tas, ias,
lat, lon, alt, pitch, bank, hdgT,
mach,
vs = ipc.readStruct(	0x02B4, "3UD",
			0x0560, "3DD", "2SD", "1UD",
			0x11C6, "1UW",
			0x0842, "1SW")

-- and convert it from FS units to units we like
gs = (gs * 3600) / (65536 * 1852)
tas = tas / 128
ias = ias / 128
mach = mach / 20480
vs = vs * -3.28084

lat = lat * 90 / (10001750 * 65536 * 65536)
lon = lon * 360 /  (65536 * 65536 * 65536 * 65536)
alt = alt * 3.28084 / (65536 * 65536)
pitch = pitch * 360 / (65536 * 65536)
bank = bank * 360 / (65536 * 65536)
hdgT = hdgT * 360 / (65536 * 65536)

--alter them all to values we want to fool other FSUIPC clients to believe
gs = gs + 100
tas = tas / 2
ias = ias * 2
mach = mach * 2
vs = vs * 2

lat = -lat
lon = -lon
alt = alt + 1000
pitch = pitch * 2
bank = bank * 2
hdgT = 360 - hdgT

-- convert them back
gs = (gs / 3600) * (65536 * 1852)
tas = tas * 128
ias = ias * 128
mach = mach * 20480
vs = vs / -3.28084

lat = (lat / 90) * (10001750 * 65536 * 65536)
lon = (lon / 360) * (65536 * 65536 * 65536 * 65536)
alt = (alt / 3.28084) * (65536 * 65536)
pitch = (pitch / 360) * (65536 * 65536)
bank = (bank / 360) * (65536 * 65536)
hdgT = (hdgT / 360) * (65536 * 65536)

-- and write them via 0024 as overrides to those being read from FSX
ipc.writeStruct(0x0024, "1UW", 0x02B4, "1UW", 3 * 4, "3UD", gs, tas, ias)
ipc.writeStruct(0x0024, "1UW", 0x0560, "1UW", (3 * 8) + (2 * 4) + 4, "3DD", lat, lon, alt, "2SD", pitch, bank, "1UD", hdgT)
ipc.writeStruct(0x0024, "1UW", 0x11C6, "1UW", 2, "1UW", mach)
ipc.writeStruct(0x0024, "1UW", 0x0842, "1UW", 2, "1SW", vs)

-- Sleep for 50 mSecs so the update gets done roughly 20 times per second
ipc.sleep(50)

end

-- Now undo the overrides (otherwise they'll take about 12 seconds to die, with frozen values provided!)
ipc.writeStruct(0x0024, "1UW", 0x02B4, "1UW", 0)
ipc.writeStruct(0x0024, "1UW", 0x0560, "1UW", 0)
ipc.writeStruct(0x0024, "1UW", 0x11C6, "1UW", 0)
ipc.writeStruct(0x0024, "1UW", 0x0842, "1UW", 0)

